@@ -7,7 +7,7 @@
 
 class KSVApplication : public KUniqueApplication
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
